@@ -342,7 +342,7 @@ module SiSU_Syntax
           end
         end
         dob.obj.gsub!(/<(https?:\/\/\S+?)>/,'< \1 >')                                   #catch problem markup
-        dob.obj.gsub!(/<:=(\S+?)>/,'{ c_\1.png 14x14 }http://www.jus.uio.no/sisu')      #adjustment 2005w30
+        dob.obj.gsub!(/<:=(\S+?)>/,'{ c_\1.png 14x14 }image')
         dob.obj.gsub!(/<!(\S+)!>/,'<:\1>')                                              #escaped special character
         dob.obj.gsub!(/&nbsp;/,"#{Mx[:nbsp]}")                                          #escaped special character
         dob.obj.gsub!(/\\~/,"#{Mx[:gl_o]}#126#{Mx[:gl_c]}")                             #escaped special character
